# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and
this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0](https://github.com/sbrudenell/btrfs2s3/compare/v0.0.5...v1.0.0) - 2024-09-12

### Added

- First official release
- Programmatic interface still to be stabilized
